@@ -1,5 +1,3 @@
-from . import function_parser
-from .variables import ExposedValue, add_exposed_value, get_exposed_values
 from .func import (
     exposed_method,
     get_exposed_methods,
@@ -11,8 +9,13 @@ from .func import (
     expose_method,
 )
 
+from . import function_parser
+from .variables import ExposedValue, add_exposed_value, get_exposed_values
+from . import func
 
-__version__ = "0.2.2"
+from .function_parser.custom_wrapper import controlled_wrapper, update_wrapper
+
+__version__ = "0.3.2"
 
 __all__ = [
     "function_parser",
@@ -28,4 +31,7 @@ __all__ = [
     "FunctionOutputParam",
     "is_exposed_method",
     "expose_method",
+    "func",
+    "controlled_wrapper",
+    "update_wrapper",
 ]
